@@ -10,7 +10,7 @@ use Cwd 'abs_path';
 # use Debug::ShowStuff::ShowVar;
 
 # version
-our $VERSION = '0.3';
+our $VERSION = '0.4';
 
 
 #------------------------------------------------------------------------------
@@ -112,6 +112,7 @@ our (@EXPORT);
 @EXPORT = qw[
 	go_script_dir
 	rtplan
+	rtdiag
 	rtcounts
 	rtok
 	rtcomp
@@ -168,6 +169,9 @@ tests. C<go_script_dir()> takes no params:
 sub go_script_dir {
 	my ($script_dir);
 	
+	# TESTING
+	# println subname(); ##i
+	
 	# load basename module
 	require File::Basename;
 	
@@ -186,7 +190,7 @@ sub go_script_dir {
 	}
 	
 	# go to directory
-	chdir($script_dir);
+	chdir($script_dir) or die 'go-script-dir-chdir-fail: unable to chdir to script directory';
 }
 #
 # go_script_dir
@@ -242,6 +246,19 @@ sub rtplan {
 #------------------------------------------------------------------------------
 
 
+#------------------------------------------------------------------------------
+# rtdiag
+#
+sub rtdiag {
+	my (@msgs) = @_;
+	my $tb = Test::Toolbox->builder;
+	return $tb->diag(@msgs);
+}
+#
+# rtdiag
+#------------------------------------------------------------------------------
+
+
 #------------------------------------------------------------------------------
 # rtcounts
 #
@@ -461,8 +478,8 @@ sub rtcomp {
 		}
 		
 		print
-			"got:         ", rtrim(define $got), "\n",
-			"should:      ", rtrim(define $should), "\n",
+			"got:         ", rtrim(define($got)), "\n",
+			"should:      ", rtrim(define($should)), "\n",
 			"----------------------------------------------------------\n";
 	}
 	
@@ -1246,6 +1263,50 @@ sub comp_sorter {
 
 
 
+#------------------------------------------------------------------------------
+# ltrim, rtrim
+#
+sub ltrim {
+	my ($rv) = @_;
+	
+	if (defined $rv)
+		{ $rv =~ s|\s+$||s }
+	
+	return $rv;
+}
+
+sub rtrim {
+	my ($rv) = @_;
+	
+	if (defined $rv)
+		{ $rv =~ s|^\s+||s }
+	
+	return $rv;
+}
+#
+# ltrim, rtrim
+#------------------------------------------------------------------------------
+
+
+
+#------------------------------------------------------------------------------
+# define
+#
+sub define {
+	my ($val) = @_;
+	
+	# if defined, return it
+	if (defined $val)
+		{ return $val }
+	
+	# else return empty string
+	return '';
+}
+#
+# define
+#------------------------------------------------------------------------------
+
+
 #------------------------------------------------------------------------------
 # collapse
 #
@@ -1292,7 +1353,7 @@ F<miko@idocs.com>
 
 =head1 VERSION
 
-Version: 0.03
+Version: 0.04
 
 =head1 HISTORY
 
@@ -1310,6 +1371,15 @@ Fixed dependency problem. Should not have been using String::Util.
 
 Added private sub collapse() which should have been in there all along.
 
+=item * Version 0.04 Aug 26, 2016
+
+Added private subs define(), rtrim(), ltrim() which should have been there
+all along.
+
+Added rtdiag().  Not sure how to test rtdiag(), so for now no tests for that.
+
+May have fixed test for rtfile().
+
 =back
 
 =cut
@@ -1335,6 +1405,7 @@ Added private sub collapse() which should have been in there all along.
 	# test scripts
 	test_scripts : {
 		'Toolbox/tests/tests.pl' : 1,
+		'Toolbox/tests/myfile.txt' : 1,
 	},
 }
 #
